Learn R Programming

schoolmath (version 0.5.1)

is.decimal: checks if a number is decimal or integer and returns TRUE for decimal

Description

checks if a number is decimal or integer and returns TRUE for decimal

Usage

is.decimal(x)

Value

true or false

Arguments

x

a vector with numbers to check #'

Examples

Run this code
is.decimal(40.15) # will return TRUE
is.decimal(4015)  # will return FALSE

Run the code above in your browser using DataLab