Learn R Programming

schoolmath (version 0.5.1)

is.whole: checks if a number is decimal or integer and returns FALSE for decimal

Description

checks if a number is decimal or integer and returns FALSE for decimal

Usage

is.whole(x)

Value

true or false

Arguments

x

a vector with numbers to check #'

Examples

Run this code
is.whole(40.15) # will return FALSE
is.whole(4015)  # will return TRUE

Run the code above in your browser using DataLab