powered by
A real positive number is defined here as a number greater than or equal to zero.
is.real.positive(x)
A logical vector of the same length as `x`.
A numeric vector.
is.real.positive(-3) # FALSE is.real.positive(0) # TRUE x <- c(0, -1, -2, 3.02, 4, -5.2, 6, -7) is.real.positive(x)
Run the code above in your browser using DataLab